AutoPIL — Control Plane

AP
AutoPIL
Control Plane
Connect with your API key
Paste the API key printed by the server on first start. It begins with `apl_`
Total Events
—
Allowed
—
Denied
—
Active Sessions
—
Policies
—
Decision Breakdown
Recent Events

Decision | Agent Role | Source | Time
--- | --- | --- | ---
Loading…

All Audit Events

Decision | Session | Agent Role | Source | Query | Policy | Time
--- | --- | --- | --- | --- | --- | ---
Loading…

Session Lookup

Decision | Agent Role | Source | Query | Hash | Reason | Time
--- | --- | --- | --- | --- | --- | ---
Enter a session ID above to view its audit trail.

Policies
Loading…
New Policy
Policy Name
Name is required.
Agent Role
Agent role is required.
Max Sensitivity
Allowed Sources (empty = all non-denied)
Denied Sources
Version History
Loading…